DIModule class abstract

An abstract base class that defines a contract for dependency injection modules.

Classes implementing or extending DIModule are responsible for organizing and registering specific sets of dependencies (e.g., services, repositories, BLoCs) into the service locator.

Implementers

Constructors

DIModule()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(GetIt injector) → void
Registers dependencies into the provided GetIt container.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited