register method
Registers the dependencies managed by this module into the GetIt injector.
This method is called during the application initialization phase.
Implementation
@override
void register(GetIt injector) {
// Register AppLogger as a lazy singleton.
// It will only be instantiated when it is requested for the first time.
injector.registerLazySingleton<ResultexLogger>(() => ResultexLogger());
}