critical abstract method

void critical(
  1. String message, {
  2. Object? error,
  3. StackTrace? stackTrace,
})

Logs a highly critical system failure that requires immediate operator attention.

Use this when the application encounters unrecoverable states or catastrophic crashes.

Implementation

void critical(String message, {Object? error, StackTrace? stackTrace});