debug abstract method

void debug(
  1. String message, {
  2. Object? error,
  3. StackTrace? stackTrace,
})

Logs a debug message with optional error and stack trace context.

Use this for verbose technical details that are helpful during development and troubleshooting phases.

Implementation

void debug(String message, {Object? error, StackTrace? stackTrace});