info abstract method
Logs an informational message.
Use this for tracking normal application flow and standard operational insights.
Implementation
void info(String message);
Logs an informational message.
Use this for tracking normal application flow and standard operational insights.
void info(String message);