ResultexLoggerModule class
A dependency injection module responsible for registering the AppLogger.
This module extends DIModule to integrate with the application's dependency injection lifecycle.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register(
GetIt injector) → void -
Registers the dependencies managed by this module into the
GetItinjector.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited