info abstract method
Logs a general operational milestone, high-level lifecycle change, or standard insight.
Use this for tracking normal, healthy, and expected application behaviors.
Implementation
void info(String message);
Logs a general operational milestone, high-level lifecycle change, or standard insight.
Use this for tracking normal, healthy, and expected application behaviors.
void info(String message);