warning abstract method
Logs a warning message.
Use this to highlight potentially harmful situations, unexpected events, or non-fatal deviations from the standard flow.
Implementation
void warning(String message);
Logs a warning message.
Use this to highlight potentially harmful situations, unexpected events, or non-fatal deviations from the standard flow.
void warning(String message);